Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Action ¶
type Action struct {
// contains filtered or unexported fields
}
Action is a type to hold the content needed for an upcoming action. An Action can be of type 'tool' or 'user', e.q. it is meant to be executed by a tool or a user.
func (Action) Reason ¶
Reason reports if the action provides a reason. If true the reason is returned.
Click to show internal directories.
Click to hide internal directories.